@@ -1,3 +1,34 @@
+/**
+ * pdfXtk-Extras - PDF Extraction Toolkit Extras
+ * Copyright (c) by the authors/contributors.  All rights reserved.
+ * This project includes code from PDFBox and TouchGraph.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions are met:
+ *
+ * 1. Redistributions of source code must retain the above copyright notice,
+ *    this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright notice,
+ *    this list of conditions and the following disclaimer in the documentation
+ *    and/or other materials provided with the distribution.
+ * 3. Neither the names pdfXtk or PDF Extraction Toolkit; nor the names of its
+ *    contributors may be used to endorse or promote products derived from this
+ *    software without specific prior written permission.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
+ * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
+ * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+ * DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR ANY
+ * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+ * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
+ * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+ * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+ * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+ *
+ * http://pdfxtk.sourceforge.net
+ *
+ */
 package at.ac.tuwien.dbai.pdfwrap.gui;
 
 import iiuf.awt.BorderLayout;
@@ -12,33 +43,23 @@ import iiuf.xmillum.IllumSource;
 import iiuf.xmillum.StatusListener;
 import iiuf.xmillum.Window;
 import iiuf.xmillum.WindowCreator;
-import iiuf.xmillum.XMIllumFrame;
 
-import java.awt.CardLayout;
-import java.awt.Color;
 import java.awt.Component;
 import java.awt.Container;
 import java.awt.Dimension;
 import java.awt.Font;
-import java.awt.GridBagConstraints;
-import java.awt.GridBagLayout;
 import java.awt.GridLayout;
 import java.awt.Point;
 import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
-import java.awt.event.FocusEvent;
-import java.awt.event.FocusListener;
 import java.awt.event.KeyEvent;
 import java.awt.event.WindowAdapter;
 import java.awt.event.WindowEvent;
-import java.io.BufferedReader;
 import java.io.File;
 import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.FileOutputStream;
 import java.io.IOException;
-import java.io.InputStream;
-import java.io.InputStreamReader;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
 import java.net.MalformedURLException;
@@ -46,7 +67,6 @@ import java.net.URL;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.Hashtable;
-import java.util.Iterator;
 import java.util.List;
 
 import javax.swing.AbstractButton;
@@ -71,8 +91,6 @@ import javax.swing.JScrollPane;
 import javax.swing.JSpinner;
 import javax.swing.JSplitPane;
 import javax.swing.JTabbedPane;
-import javax.swing.JTextField;
-import javax.swing.JTextPane;
 import javax.swing.JToggleButton;
 import javax.swing.SpinnerModel;
 import javax.swing.SpinnerNumberModel;
@@ -86,34 +104,29 @@ import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 
-//import org.apache.log4j.Logger;
-//import org.apache.log4j.PropertyConfigurator;
 import org.w3c.dom.DOMImplementation;
 import org.w3c.dom.Document;
 import org.w3c.dom.Element;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 
+import at.ac.tuwien.dbai.pdfwrap.CustomPageProcessor;
 import at.ac.tuwien.dbai.pdfwrap.GraphMatcher;
 import at.ac.tuwien.dbai.pdfwrap.ProcessFile;
 import at.ac.tuwien.dbai.pdfwrap.analysis.PageProcessor;
 import at.ac.tuwien.dbai.pdfwrap.gui.graphbrowser.DocGBPanel;
 import at.ac.tuwien.dbai.pdfwrap.gui.graphbrowser.DocWrapperUI;
-import at.ac.tuwien.dbai.pdfwrap.model.graph.AdjacencyEdge;
+import at.ac.tuwien.dbai.pdfwrap.model.document.GenericSegment;
+import at.ac.tuwien.dbai.pdfwrap.model.document.Page;
 import at.ac.tuwien.dbai.pdfwrap.model.graph.AdjacencyGraph;
-import at.ac.tuwien.dbai.pdfwrap.model.graph.DocEdge;
 import at.ac.tuwien.dbai.pdfwrap.model.graph.DocGraphEltSet;
 import at.ac.tuwien.dbai.pdfwrap.model.graph.DocNode;
 import at.ac.tuwien.dbai.pdfwrap.model.graph.DocumentGraph;
 import at.ac.tuwien.dbai.pdfwrap.model.graph.WrappingInstance;
-import at.ac.tuwien.dbai.pdfwrap.model.document.*;
 import at.ac.tuwien.dbai.pdfwrap.utils.ListUtils;
 import at.ac.tuwien.dbai.pdfwrap.utils.SegmentUtils;
 import at.ac.tuwien.dbai.pdfwrap.utils.Utils;
 
-//import com.hp.hpl.jena.ontology.OntModel;
-import com.touchgraph.graphlayout.Node;
-
 /**
  * GUI
  * 
@@ -128,11 +141,13 @@ import com.touchgraph.graphlayout.Node;
  */
 public class GUI
 {
-	protected final static String newline = "\n";
+	public final static String newline = "\n";
 	
 //	public final static boolean DISPLAY_INSTRUCTIONS = false;
 	
-	public final static int DEFAULT_SEGMENTATION_MODE = PageProcessor.PP_MERGED_LINES;
+//	2011-02-25 MODIFICATION -- all occurrences of PageProcessor changed to
+//	CustomPageProcessor
+	public final static int DEFAULT_SEGMENTATION_MODE = CustomPageProcessor.PP_MERGED_LINES;
 	
 //	public final static float dividerRatio = 0.9f;
 	public final static int dividerLocation = 20;
@@ -256,7 +271,7 @@ public class GUI
 
 	protected int segmentationMode;
 	protected boolean processSpaces = false;
-	protected boolean rulingLines = false;
+	protected boolean rulingLines = true; // 2011-03-03 MODIFICATION
 	
 	// boolean wrapperGraphAdded;
 
@@ -438,6 +453,9 @@ public class GUI
 		toolBar.add(butViewGraph);
 		toolBar.add(butFindInstances);
 		toolBar.add(butSaveWrapper);
+		// 2011-02-25 ADDITION
+		toolBar.add(butPrintResult);
+		// 2011-02-25 END OF ADDITION
 		
 		return toolBar;
 	}
@@ -452,7 +470,7 @@ public class GUI
 		fragmentButton.setSelected(true);
 		ActionListener fragmentAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				segmentationMode = PageProcessor.PP_FRAGMENT;
+				segmentationMode = CustomPageProcessor.PP_FRAGMENT;
 			}
 		};
 		fragmentButton.addActionListener(fragmentAction);
@@ -464,7 +482,7 @@ public class GUI
 		charButton.setSelected(true);
 		ActionListener charAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				segmentationMode = PageProcessor.PP_CHAR;
+				segmentationMode = CustomPageProcessor.PP_CHAR;
 			}
 		};
 		charButton.addActionListener(charAction);
@@ -475,7 +493,7 @@ public class GUI
 		lineButton.setSelected(true);
 		ActionListener lineAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				segmentationMode = PageProcessor.PP_LINE;
+				segmentationMode = CustomPageProcessor.PP_LINE;
 			}
 		};
 		lineButton.addActionListener(lineAction);
@@ -485,7 +503,7 @@ public class GUI
 		blockButton.setMnemonic(KeyEvent.VK_B);
 		ActionListener blockAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				segmentationMode = PageProcessor.PP_BLOCK;
+				segmentationMode = CustomPageProcessor.PP_BLOCK;
 			}
 		};
 		blockButton.addActionListener(blockAction);
@@ -495,7 +513,7 @@ public class GUI
 		atomicLinesButton.setMnemonic(KeyEvent.VK_M);
 		ActionListener atomicLinesAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				segmentationMode = PageProcessor.PP_MERGED_LINES;
+				segmentationMode = CustomPageProcessor.PP_MERGED_LINES;
 			}
 		};
 		atomicLinesButton.addActionListener(atomicLinesAction);
@@ -510,27 +528,52 @@ public class GUI
 			}
 		};
 		structButton.addActionListener(structAction);
+		*/
+		
+		// 2011-02-24 MODIFICATION FOR EXTRAS - TABLE METHODS
 		
 		JRadioButton columnButton = new JRadioButton("Columns");
 //		columnButton.setFont(columnButton.getFont().deriveFont(0));
 		columnButton.setMnemonic(KeyEvent.VK_C);
 		ActionListener columnAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				segmentationMode = PageProcessor.PP_COLUMN;
+				segmentationMode = CustomPageProcessor.PP_COLUMN;
 			}
 		};
 		columnButton.addActionListener(columnAction);
 		
+		JRadioButton rTableButton = new JRadioButton("R Tables");
+//		tableButton.setFont(tableButton.getFont().deriveFont(0));
+		rTableButton.setMnemonic(KeyEvent.VK_R);
+		ActionListener rTableAction = new ActionListener() {
+			public void actionPerformed(ActionEvent e) {
+				segmentationMode = CustomPageProcessor.PP_R_TABLE;
+			}
+		};
+		rTableButton.addActionListener(rTableAction);
+		
+		JRadioButton nrTableButton = new JRadioButton("NR Tables");
+//		tableButton.setFont(tableButton.getFont().deriveFont(0));
+		nrTableButton.setMnemonic(KeyEvent.VK_N);
+		ActionListener nrTableAction = new ActionListener() {
+			public void actionPerformed(ActionEvent e) {
+				segmentationMode = CustomPageProcessor.PP_NR_TABLE;
+			}
+		};
+		nrTableButton.addActionListener(nrTableAction);
+		
 		JRadioButton tableButton = new JRadioButton("Tables");
 //		tableButton.setFont(tableButton.getFont().deriveFont(0));
 		tableButton.setMnemonic(KeyEvent.VK_T);
 		ActionListener tableAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
-				segmentationMode = PageProcessor.PP_TABLE;
+				segmentationMode = CustomPageProcessor.PP_TABLE;
 			}
 		};
 		tableButton.addActionListener(tableAction);
-		 */
+		 
+		
+		// 2011-02-24 END OF MODIFICATION
 		
 		JCheckBox spaceButton = new JCheckBox("Remove spaces");
 	    spaceButton.setMnemonic(KeyEvent.VK_S); 
@@ -545,7 +588,7 @@ public class GUI
 		spaceButton.addActionListener(spaceAction);
 		
 		JCheckBox rulingLinesButton = new JCheckBox("Ruling lines");
-	    rulingLinesButton.setMnemonic(KeyEvent.VK_N); 
+	    rulingLinesButton.setMnemonic(KeyEvent.VK_G); 
 	    rulingLinesButton.setSelected(false);
 	    ActionListener rulingLinesAction = new ActionListener() {
 			public void actionPerformed(ActionEvent e) {
@@ -564,9 +607,13 @@ public class GUI
 		group.add(blockButton);
 		group.add(atomicLinesButton);
 //		group.add(structButton);
-//		group.add(columnButton);
-//		group.add(tableButton);
-
+		// 2011-02-24 MODIFICATION FOR EXTRAS - TABLE METHODS
+		group.add(columnButton);
+		group.add(rTableButton);
+		group.add(nrTableButton);
+		group.add(tableButton);
+		// 2011-02-24 END OF MODIFICATION
+		
 		JPanel segmentationPanel = new JPanel();
 		segmentationPanel.setLayout(new BoxLayout(segmentationPanel,
 				BoxLayout.X_AXIS));
@@ -583,9 +630,15 @@ public class GUI
 		seg1.add(fragmentButton);
 		seg1.add(lineButton);
 		seg1.add(atomicLinesButton);
-		seg2.add(blockButton);
+		seg1.add(blockButton);
 //		seg2.add(structButton);
-
+		// 2011-02-24 MODIFICATION FOR EXTRAS - TABLE METHODS
+		seg2.add(columnButton);
+		seg2.add(rTableButton);
+		seg2.add(nrTableButton);
+		seg2.add(tableButton);
+		// 2011-24-24 END OF MODIFICATION
+		
 		segmentationPanel.add(seg1);
 		segmentationPanel.add(seg2);
 		
@@ -1199,7 +1252,7 @@ public class GUI
 						// TODO: check if we want this to be highlighted...
 						// TODO: this is how to select default layers!!
 						if (layers[i].equals("Clusters")
-								|| layers[i].equals("Potential Tables")
+//								|| layers[i].equals("Potential Tables") // 2011-03-03 MODIFICATION commented out
 								|| layers[i].equals("Tables")
 								|| layers[i].equals("Page Image")
 								|| layers[i].equals("Found instances")
@@ -1746,12 +1799,11 @@ public class GUI
 				
 				// process the pdf file, using object
 				statusList.addMessage("Processing file...");
-
+				
 				List<Page> thePages;
 				List<AdjacencyGraph<GenericSegment>> theGraphs =
 					new ArrayList<AdjacencyGraph<GenericSegment>>();
 				
-				/*
 				boolean pdf = true;
 				if (inFile.getName().endsWith("png") ||
 					inFile.getName().endsWith("tif") ||
@@ -1763,10 +1815,9 @@ public class GUI
 					inFile.getName().endsWith("TIFF") ||
 					inFile.getName().endsWith("JPG") ||
 					inFile.getName().endsWith("JPEG")) pdf = false;
-				*/
 				
 				// set up page processor object
-		        PageProcessor pp = new PageProcessor();
+		        PageProcessor pp = new CustomPageProcessor();
 		        pp.setProcessType(segmentationMode);
 		        pp.setRulingLines(rulingLines);
 		        pp.setProcessSpaces(processSpaces);
@@ -1849,8 +1900,7 @@ public class GUI
 //				String s;
 				
 				String[] sa;
-//				if (pdf)
-				if (true)
+				if (pdf)
 				{
 					/*
 					s = (Utils.GHOSTSCRIPT_EXECUTABLE
@@ -1872,16 +1922,17 @@ public class GUI
 						"-sOutputFile=" + Utils.getRootDir() + File.separator + "output.png",
 						inFile.getPath()};
 				}
-				/*
-				else // for OCR only
+				else
 				{
-//					s = (Utils.COPY_EXECUTABLE + " " + inFile.getPath() + " " + 
-//						Utils.getRootDir() + File.separator + "output.png ") + "";
+					/*
+					s = (Utils.COPY_EXECUTABLE + " " + inFile.getPath() + " " + 
+						Utils.getRootDir() + File.separator + "output.png ") + "";
+					*/
 					
 					sa = new String[] {COPY_EXECUTABLE, inFile.getPath(),
 						Utils.getRootDir() + File.separator + "output.png"};
 				}
-				*/
+				
 				if (true){
 //				if (newFile) {
 					
@@ -2021,9 +2072,9 @@ public class GUI
         Element docElement = resultDocument.getDocumentElement();
         
         String granularity = "block";
-        if (segmentationMode == PageProcessor.PP_MERGED_LINES)
+        if (segmentationMode == CustomPageProcessor.PP_MERGED_LINES)
         	granularity = "line";
-        if (segmentationMode == PageProcessor.PP_LINE)
+        if (segmentationMode == CustomPageProcessor.PP_LINE)
         	granularity = "raw-line";
         
         docElement.setAttribute("granularity", granularity);
