@@ -49,8 +49,6 @@
 
 package com.touchgraph.graphlayout;
 
-import at.ac.tuwien.dbai.pdfwrap.gui.graphbrowser.DocGBPanel;
-
 import  com.touchgraph.graphlayout.interaction.*;
 import  com.touchgraph.graphlayout.graphelements.*;
 
@@ -59,10 +57,6 @@ import  java.awt.event.*;
 import  javax.swing.*;
 import  java.util.*;
 
-// 2011-02-02 This class does change the functionality of the TouchGraph class
-// select is an Object instead of a Node, which also allows edges to be selected
-// extending the class does not allow return types to be overriden
-
 /** TGPanel contains code for drawing the graph, and storing which nodes
   * are selected, and which ones the mouse is over.
   *
@@ -75,11 +69,9 @@ import  java.util.*;
   * http://java.sun.com/applets/jdk/1.1/demo/GraphLayout/Graph.java
   * </b></p>
   *
-  * @author Tamir Hassan, hassan@dbai.tuwien.ac.at
-  * @version GraphWrap Beta 1
   * @author   Alexander Shapiro
   * @author   Murray Altheim  (2001-11-06; 2002-01-14 cleanup)
-  * @version  1.21  $Id: TGPanel.java,v 1.1 2006/05/17 06:37:28 hassan Exp $
+  * @version  1.21  $Id: TGPanel.java,v 1.59 2002/04/01 05:51:55 x_ander Exp $
   */
 public class TGPanel extends JPanel {
 
@@ -99,9 +91,10 @@ public class TGPanel extends JPanel {
     protected Node mouseOverN;  //mouseOverN is the node the mouse is over
     protected boolean maintainMouseOver = false; //If true, then don't change mouseOverN or mouseOverE
 
-    //protected Node select;
+//  2011-02-18 modification
+//  protected Node select;
     protected Object select;
-    
+
     Node dragNode; //Node currently being dragged
 
     protected Point mousePos; //Mouse location, updated in the mouseMotionListener
@@ -116,17 +109,12 @@ public class TGPanel extends JPanel {
     AdjustOriginLens adjustOriginLens;
     SwitchSelectUI switchSelectUI;
 
-    protected DocGBPanel docGBPanel;
-    
   // ............
 
    /** Default constructor.
      */
-    public TGPanel(DocGBPanel docGBPanel) 
+    public TGPanel()
     {
-    	// added 3.11.08 to enable status bar options
-    	this.docGBPanel = docGBPanel;
-    	
         setLayout(null);
 
         setGraphEltSet(new GraphEltSet());
@@ -300,6 +288,8 @@ public class TGPanel extends JPanel {
         }
     }
 
+//  2011-02-18 modification
+//  public Node getSelect() {
     public Object getSelect() {
         return select;
     }
@@ -464,8 +454,6 @@ public class TGPanel extends JPanel {
 
     public void clearSelect() {
         if ( select != null ) {
-        	//if (select instanceof DocEdge)
-			//	((DocEdge)select).setSelected(false);
             select = null;
             repaint();
         }
@@ -477,23 +465,12 @@ public class TGPanel extends JPanel {
         setSelect(getGES().getFirstNode());
     }
 
-	public void setSelect( Object obj ) {
-		if (obj != null)
-		{
-			// dependency removed :)
-			//if (select !=  null && select instanceof DocEdge)
-			//	((DocEdge)select).setSelected(false);
-			select = obj;
-			//if (obj instanceof DocEdge)
-			//	((DocEdge)obj).setSelected(true);
-			repaint();
-		}
-		else
-		{
-			clearSelect();
-		}
-		docGBPanel.updateStatusBarControls();
-	}
+    public void setSelect( Node node ) {
+          if ( node != null ) {
+              select = node;
+              repaint();
+          } else if ( node == null ) clearSelect();
+    }
 
     public void multiSelect( TGPoint2D from, TGPoint2D to ) {
         final double minX,minY,maxX,maxY;
@@ -874,11 +851,12 @@ public class TGPanel extends JPanel {
         }
 
         if ( select != null ) { //Make the selected node appear on top.
+//        	2011-02-18 modification
+//          select.paint(offgraphics, this);
         	if (select instanceof Node)
         		((Node)select).paint(offgraphics, this);
-        	// looks funny if we do this!
-        	//else if (select instanceof Edge)
-        	//	((Edge)select).paint(offgraphics, this);
+        	else if (select instanceof Edge)
+        		((Edge)select).paint(offgraphics, this);
         }
 
         if ( mouseOverN != null ) { //Make the node the mouse is over appear on top.
@@ -895,7 +873,7 @@ public class TGPanel extends JPanel {
         
     }
 
-/*
+
     public static void main( String[] args ) {
 
         JFrame frame;
@@ -919,5 +897,5 @@ public class TGPanel extends JPanel {
         frame.setSize(500,500);
         frame.setVisible(true);
     }
-*/
+
 } // end com.touchgraph.graphlayout.TGPanel
